@@ -4,6 +4,8 @@ COVID data, such as API connections, URLs for requests and files location,
 commonly used in data collection modules
 """
 
+from pathlib import Path
+
 # Colombia COVID data config:
 from sodapy import Socrata
 
@@ -27,3 +29,6 @@ OWID_HOST = "135.181.41.20"
 
 # SINAN data config:
 SINAN_LOG_PATH = "/tmp/sinan_fetch.log"
+_sinan_data = Path().home() / "pysus"
+_sinan_data.mkdir(exist_ok=True)
+PYSUS_DATA_PATH = str(_sinan_data)
