@@ -3,7 +3,7 @@ from pathlib import PosixPath
 from loguru import logger
 from pysus.online_data import SINAN
 
-from epigraphhub.data._config import SINAN_LOG_PATH
+from epigraphhub.data._config import PYSUS_DATA_PATH, SINAN_LOG_PATH
 
 logger.add(SINAN_LOG_PATH, retention="7 days")
 
@@ -23,7 +23,7 @@ def download(disease: str):
     Returns:
         parquets_paths_list list(PosixPath) : A list with all parquets dirs.
     """
-    
-    SINAN.download_all_years_in_chunks(disease)
-    
-    logger.info(f"All years for {disease} downloaded at /tmp/pysus")
+
+    SINAN.download_all_years_in_chunks(disease, data_dir=PYSUS_DATA_PATH)
+
+    logger.info(f"All years for {disease} downloaded at {PYSUS_DATA_PATH}")
